#
# Copyright (c) 2006-2012, Prometheus Research, LLC
#

from django.contrib.auth.decorators import login_required
from django.http import HttpResponse
from django.core.urlresolvers import reverse
from django.db import transaction
from . import instance

def to_environ(request):
    environ = request.META.copy()
    prefix = reverse(gateway)
    if prefix.endswith('/'):
        prefix = prefix[:-1]
    if isinstance(environ['PATH_INFO'], unicode):
        environ['PATH_INFO'] = environ['PATH_INFO'].encode('utf-8')
    if isinstance(environ['SCRIPT_NAME'], unicode):
        environ['SCRIPT_NAME'] = environ['SCRIPT_NAME'].encode('utf-8')
    assert environ['PATH_INFO'].startswith(prefix)
    assert environ['SCRIPT_NAME'] == ''
    environ['SCRIPT_NAME'] = prefix
    environ['PATH_INFO'] = environ['PATH_INFO'][len(prefix):]
    return environ

@login_required
@transaction.commit_manually
def gateway(request):
    class output:
        status = None
        headers = None
        body = None
    environ = to_environ(request)
    def start_response(status, headers, exc_info=None):
        output.status = status
        output.headers = headers
    output.body = ''.join(instance(environ, start_response))
    response = HttpResponse(output.body, status=int(output.status.split()[0]))
    for header, value in output.headers:
        response[header] = value
    return response




#
# Copyright (c) 2006-2012, Prometheus Research, LLC
#

from htsql import HTSQL
from django.conf import settings

CONFIG = getattr(settings, 'HTSQL_CONFIG', {})
DEFAULT_CONFIG = {
        'tweak.django': {},
}

instance = HTSQL(None, CONFIG, DEFAULT_CONFIG)
produce = instance.produce




#
# Copyright (c) 2006-2012, Prometheus Research, LLC
#


#
# To install HTSQL-DJANGO, run `python setup.py install`.
#


from setuptools import setup
import os.path


NAME = "HTSQL-DJANGO"
VERSION = "2.3.1"
DESCRIPTION = "A Database Query Language (Django gateway)"
LONG_DESCRIPTION = open(os.path.join(os.path.dirname(__file__),
                                     "README")).read()
AUTHOR = "Clark C. Evans and Kirill Simonov; Prometheus Research, LLC"
AUTHOR_EMAIL = "cce@clarkevans.com, xi@resolvent.net"
LICENSE = "AGPLv3 or Permissive for use with Open Source databases"
KEYWORDS = "sql relational database query language"
PLATFORMS = "Any"
URL = "http://htsql.org/"
CLASSIFIERS = """
""".strip().splitlines() or None
PACKAGE_DIR = {'': 'src'}
INCLUDE_PACKAGE_DATA = True
ZIP_SAFE = False
PACKAGES = """
htsql_django
""".strip().splitlines()
INSTALL_REQUIRES = """
HTSQL
Django
""".strip().splitlines()
CONSOLE_SCRIPTS = """
""".strip().splitlines() or None
HTSQL_ROUTINES = """
""".strip().splitlines() or None
HTSQL_ADDONS = """
""".strip().splitlines() or None
ENTRY_POINTS = {}
if CONSOLE_SCRIPTS:
    ENTRY_POINTS['console_scripts'] = CONSOLE_SCRIPTS
if HTSQL_ROUTINES:
    ENTRY_POINTS['htsql.routines'] = HTSQL_ROUTINES
if HTSQL_ADDONS:
    ENTRY_POINTS['htsql.addons'] = HTSQL_ADDONS


setup(name=NAME,
      version=VERSION,
      description=DESCRIPTION,
      long_description=LONG_DESCRIPTION,
      author=AUTHOR,
      author_email=AUTHOR_EMAIL,
      license=LICENSE,
      keywords=KEYWORDS,
      platforms=PLATFORMS,
      url=URL,
      classifiers=CLASSIFIERS,
      package_dir=PACKAGE_DIR,
      include_package_data=INCLUDE_PACKAGE_DATA,
      zip_safe=ZIP_SAFE,
      packages=PACKAGES,
      install_requires=INSTALL_REQUIRES,
      entry_points=ENTRY_POINTS)


